@@ -24,14 +24,18 @@ public:
         QString authStr;
         int port = -1;
     };
-    explicit Transport(const QString &type, QObject *parent);
+    explicit Transport(QObject *parent);
     ~Transport() override;
     void createTransport();
 
     [[nodiscard]] TransportInfo transportInfo() const;
     void setTransportInfo(const TransportInfo &newTransportInfo);
 
+    [[nodiscard]] int transportId() const;
+
 private:
     TransportInfo mTransportInfo;
+    int mTransportId = -1;
 };
 QDebug operator<<(QDebug d, const Transport::TransportInfo &t);
+Q_DECLARE_TYPEINFO(Transport::TransportInfo, Q_RELOCATABLE_TYPE);
